==> linuxconf-tools-1.1.src.tar.gz: linuxconf-tools-1.1/projetx/change1.cc <==
#include <string.h>
#include <misc.h>
#include <dialog.h>
#include "projet.h"
#include "projetx.m"

struct DIFF_INFO{
	const char *fichier;
	const char *ref;
};

static PAGE_VAL fct_diff(
	long mskwin,
	EVENT *cmd,
	BOUTON_FCT *but,
	void *data)
{
	return PAGE_VAL_NULL;
}

/*
	Edite le commentaire d'un fichier.
*/
static void change_editdoc(
	long mskwin,
	EVENT *cmd,
	const char *fichier,// Fichier source  documenter
	const char *ref,	// Path vers le fichier original
	const char *doc,	// Chaine a diter, contenant plusieurs lignes
	char *newdoc)		// Contiendra le rsultat
{
	char lignes[5][80];
	char *pt = lignes[0];
	int nol = 0;
	strcpy (newdoc,doc);	// Par dfaut, conserve input.
	memset (lignes,0,sizeof(lignes));
	while (*doc != '\0'){
		while (*doc != '\n' && *doc != '\0') *pt++ = *doc++;
		*pt = '\0';
		nol++;
		if (*doc == '\n'){
			pt = lignes[nol];
			doc++;
		}
	}
	PAGE_EDIT page("change_editdoc");
	page_setuptitre (&page,ref == NULL
		? MSGTIT_NEWSRC : MSGTIT_CHANGESRC,fichier);
	for (int i=0; i<5; i++){
		page_setupstring (&page,-1,lignes[i],79,50);
	}
	bouton_setupstd (&page,"save cancel reset undo");
	DIFF_INFO diff_info;
	diff_info.fichier = fichier;
	diff_info.ref = ref;
	if (ref != NULL){
		bouton_setupfct (&page,MSGBUT_DIFFS,K_NULL,fct_diff,&diff_info);
	}
	if (page.edit(mskwin,cmd)==PAGE_VAL_SAVE){
		newdoc[0] = '\0';
		for(i=0; i<5; i++){
			strcat (newdoc,lignes[i]);
			strcat (newdoc,"\n");
		}
		strip_end (newdoc);
	}
}
/*
	Prsentation des fichiers d'un projet et dition de la courte
	description des changements qu'ils ont subis.

	Retourne -1 si abandon ou erreur.
*/
int change_edit (
	USERINFO *user,
	const char *projet)
{
	PRJCTRL ctrl(user);
	int ret = -1;
	char path[MAXSIZ_PATH];
	user->makusrpath(projet,path);
	SAVEPATH save;	
	if (path_pushdir (user,path,&save) != -1){
		char *tb[200];
		int nb = ctrl.dirsource (".",WILD_ALLFILE,tb,200);
		if (nb <= 0){
			error_showdef (MSGERR_NOSOURCE,projet);
		}else{
			CHANGE_DAT change ("change.dat");
			MAKEFILE mkf ("makefile.dat",0,projet,user);
			PAGE_EDIT page ("change_edit");
			page_setuptitre (&page,MSGTIT_CHANGE);
			unsigned select=0;
			PAGE_PICK pick ("",10,&select);
			int maxlen = 0;
			// Dtermine la longueur maximum des noms de fichier
			for (int i=0; i<nb; i++){
				int len = strlen(tb[i]);
				if (len > maxlen) maxlen = len;
			}
			for (i=0; i<nb; i++){
				char *fichier = tb[i];
				char tmp[MAXSIZ_NAME+10];
				sprintf (tmp,"%-*s %s",maxlen,fichier
					,change.getdoc(fichier)==NULL
					 ? "_______" : "bla bla");
				page_setupfixestr0 (&pick,-1,tmp,-1);
			}
			page.setup (-1,&pick,0);
			bouton_setupstd (&page,"enter cancel");
			page.setspec (but);
			page.draw();
			ret = 0;
			while (1){
				PAGE_VAL ret = page.edit (mskwin,cmd);
				if (ret == PAGE_VAL_ABORT || cmd->is_load){
					break;
				}else{
					char *fichier = tb[select];
					if (ctrl.isdir (fichier)){
						char sous_projet[MAXSIZ_PATH];
						path_make (projet,fichier,sous_projet);
						path_stripsep (sous_projet,sous_projet);
						change_edit (mskwin,cmd,but,user,sous_projet);
						if (cmd->is_load) break;
					}else{
						const char *doc = change.getdoc(fichier);
						if (doc == NULL) doc = "";
						char newdoc[500];
						change_editdoc(mskwin,cmd,fichier,mkf.getref(fichier)
							,doc,newdoc);
						if (cmd->is_load) break;
						change.setdoc (fichier,newdoc);
						char tmp[MAXSIZ_NAME+10];
						sprintf (tmp,"%-*s %s",maxlen,fichier
							,newdoc[0] == '\0'
							 ? "_______" : "bla bla");
						fixestr_newstr0 (&pick,select,tmp);
						pick.drawitem (select);
					}
				}
			}
			change.save();
		}
		path_popdir (&save);
	}
	return ret;
}

==> linuxconf-tools-1.6.src.tar.gz: linuxconf-tools-1.6/projetx/change1.cc <==
#include <string.h>
#include <misc.h>
#include <dialog.h>
#include "projet.h"
#include "projetx.m"

#if 0
struct DIFF_INFO{
	const char *fichier;
	const char *ref;
};

static PAGE_VAL fct_diff(
	long mskwin,
	EVENT *cmd,
	BOUTON_FCT *but,
	void *data)
{
	return PAGE_VAL_NULL;
}

/*
	Edite le commentaire d'un fichier.
*/
static void change_editdoc(
	long mskwin,
	EVENT *cmd,
	const char *fichier,// Fichier source  documenter
	const char *ref,	// Path vers le fichier original
	const char *doc,	// Chaine a diter, contenant plusieurs lignes
	char *newdoc)		// Contiendra le rsultat
{
	char lignes[5][80];
	char *pt = lignes[0];
	int nol = 0;
	strcpy (newdoc,doc);	// Par dfaut, conserve input.
	memset (lignes,0,sizeof(lignes));
	while (*doc != '\0'){
		while (*doc != '\n' && *doc != '\0') *pt++ = *doc++;
		*pt = '\0';
		nol++;
		if (*doc == '\n'){
			pt = lignes[nol];
			doc++;
		}
	}
	PAGE_EDIT page("change_editdoc");
	page_setuptitre (&page,ref == NULL
		? MSGTIT_NEWSRC : MSGTIT_CHANGESRC,fichier);
	for (int i=0; i<5; i++){
		page_setupstring (&page,-1,lignes[i],79,50);
	}
	bouton_setupstd (&page,"save cancel reset undo");
	DIFF_INFO diff_info;
	diff_info.fichier = fichier;
	diff_info.ref = ref;
	if (ref != NULL){
		bouton_setupfct (&page,MSGBUT_DIFFS,K_NULL,fct_diff,&diff_info);
	}
	if (page.edit(mskwin,cmd)==PAGE_VAL_SAVE){
		newdoc[0] = '\0';
		for(i=0; i<5; i++){
			strcat (newdoc,lignes[i]);
			strcat (newdoc,"\n");
		}
		strip_end (newdoc);
	}
}
#endif
/*
	Prsentation des fichiers d'un projet et dition de la courte
	description des changements qu'ils ont subis.

	Retourne -1 si abandon ou erreur.
*/
int change_edit (
	USERINFO *user,
	const char *projet)
{
	PRJCTRL ctrl(user);
	int ret = -1;
	char path[MAXSIZ_PATH];
	user->makusrpath(projet,path);
	SAVEPATH save;	
	if (path_pushdir (user,path,&save) != -1){
		char *tb[200];
		int nb = ctrl.dirsource (".",WILD_ALLFILE,tb,200);
		if (nb <= 0){
			xconf_error (MSG_U(E_NOSOURCE,"Aucun fichier modifi\n"
				"pour le projet %s")
				,projet);
		}else{
			CHANGE_DAT change ("change.dat");
			MAKEFILE mkf ("makefile.dat",0,projet,user);
			DIALOG_RECORDS dia;
			dia.newf_head ("",MSG_U(H_FNAME,"File name"));
			int maxlen = 0;
			// Dtermine la longueur maximum des noms de fichier
			for (int i=0; i<nb; i++){
				int len = strlen(tb[i]);
				if (len > maxlen) maxlen = len;
			}
			for (int i=0; i<nb; i++){
				char *fichier = tb[i];
				char tmp[MAXSIZ_NAME+10];
				sprintf (tmp,"%-*s %s",maxlen,fichier
					,change.getdoc(fichier)==NULL
					 ? "_______" : "bla bla");
				dia.new_menuitem ("",tmp);
			}
			ret = 0;
			int select=0;
			while (1){
				MENU_STATUS code = dia.edit (MSG_U(T_CHANGE,"Fichiers changs")
					,"",help_nil,select);
				if (code == MENU_QUIT || code == MENU_ESCAPE){
					break;
				}else{
					char *fichier = tb[select];
					if (ctrl.isdir (fichier)){
						char sous_projet[MAXSIZ_PATH];
						path_make (projet,fichier,sous_projet);
						path_stripsep (sous_projet,sous_projet);
						change_edit (user,sous_projet);
					}else{
						#ifdef MISSING
							const char *doc = change.getdoc(fichier);
							if (doc == NULL) doc = "";
							char newdoc[500];
							change_editdoc(fichier,mkf.getref(fichier)
							,doc,newdoc);
							change.setdoc (fichier,newdoc);
							char tmp[MAXSIZ_NAME+10];
							sprintf (tmp,"%-*s %s",maxlen,fichier
								,newdoc[0] == '\0'
								 ? "_______" : "bla bla");
							fixestr_newstr0 (&pick,select,tmp);
							pick.drawitem (select);
						#else
							xconf_notice ("missing");
						#endif
					}
				}
			}
			change.save();
		}
		path_popdir (&save);
	}
	return ret;
}
